@@ -1,13 +1,12 @@
 # vi:fdm=marker fdl=0
-# $Id: Basic.pm,v 1.24 2004/03/25 17:48:56 jettero Exp $ 
+# $Id: Basic.pm,v 1.12 2003/12/06 16:35:53 jettero Exp $ 
 
-package Statistics::Basic;
+package Statisics::Basic;
 
 use strict;
-no warnings;
 use Carp;
 
-our $VERSION = "0.41.3";
+our $VERSION = "0.36";
 
 1;
 
@@ -16,9 +15,11 @@ __END__
 
 =head1 NAME
 
-    Statistics::Basic A collection of very basic statistics formulae for vectors.
+    Basic Statistics
 
 =head1 SYNOPSIS
+    
+    A collection of very basic statistics formulae for vectors.
 
     # for use with one vector:
     Statistics::Basic::Mean;
@@ -79,46 +80,12 @@ __END__
 
     If you spot any bugs, please tell me.
 
-=head1 ENV VARIABLES
-
-=head2 DEBUG
-
-   Try setting $ENV{DEBUG}=1; or $ENV{DEBUG}=2; to see the internals.
-
-   Also, from your bash prompt you can 'DEBUG=1 perl ./myprog.pl' to
-   enable debugging dynamically.
-
-=head2 UNBIAS
-
-   This module uses the sum(X - mean(X))/N definition of variance.
-   If you wish to use the unbiased, sum(X-mean(X)/(N-1) definition, then 
-   set the $ENV{UNBIAS}=1;
-
-   # And if you thought that was useful, then give a shout out to:
-   # Robert McGehee <xxxxxxxx@wso.williams.edu>, for he requested it.
-
 =head1 AUTHOR
 
     Please contact me with ANY suggestions, no matter how pedantic.
 
     Jettero Heller <japh@voltar-confed.org>
 
-=head1 COPYRIGHT
-
-    GPL!  I included a gpl.txt for your reading enjoyment.
-
-    Though, additionally, I will say that I'll be tickled if you were to
-    include this package in any commercial endeavor.  Also, any thoughts to
-    the effect that using this module will somehow make your commercial
-    package GPL should be washed away.
-
-    I hereby release you from any such silly conditions.
-
-    This package and any modifications you make to it must remain GPL.  Any
-    programs you (or your company) write shall remain yours (and under
-    whatever copyright you choose) even if you use this package's intended
-    and/or exported interfaces in them.
-
 =head1 SEE ALSO
 
     Most of the documentation is very thin.  Sorry.  The modules with their
