@@ -1,10 +1,9 @@
 # vi:fdm=marker fdl=0
-# $Id: CoVariance.pm,v 1.11 2004/03/23 13:01:42 jettero Exp $ 
+# $Id: CoVariance.pm,v 1.8 2003/12/02 22:17:28 jettero Exp $ 
 
 package Statistics::Basic::CoVariance;
 
 use strict;
-no warnings;
 use Carp;
 use Statistics::Basic::Mean;
 use Statistics::Basic::Vector;
@@ -30,10 +29,8 @@ sub new {
         } elsif( ref($v[$i]) eq "Statistics::Basic::Vector" ) {
             $this->{"v$x"} = $v[$i];
             $this->{"v$x"}->set_size( $set_size ) if defined $set_size;
-        } elsif(defined($v[$i])) {
-            croak "argument to new() must be an arrayref or Statistics::Basic::Vector";
         } else {
-            $this->{"v$x"} = new Statistics::Basic::Vector;
+            croak "argument to new() must be an arrayref or Statistics::Basic::Vector";
         }
 
         $this->{"m$x"} = (ref($m[$i]) eq "Statistics::Basic::Mean" ? 
@@ -58,11 +55,8 @@ sub recalc {
 
     my $cardinality = $c1;
 
-    $cardinality -- if $ENV{UNBIAS};
-
     unless( $cardinality > 0 ) {
-        warn "[recalc covariance] cardinality found to be 0-ish\n" if $ENV{DEBUG};
-
+        warn "[recalc covariance] cardinality found to be 0-ish\n";
         $this->{covariance} = undef;
 
         return;
@@ -183,24 +177,6 @@ __END__
 
     A machine to calculate the covariance of given vectors.
 
-=head1 ENV VARIABLES
-
-=head2 DEBUG
-
-   Try setting $ENV{DEBUG}=1; or $ENV{DEBUG}=2; to see the internals.
-
-   Also, from your bash prompt you can 'DEBUG=1 perl ./myprog.pl' to
-   enable debugging dynamically.
-
-=head2 UNBIAS
-
-   This module uses the sum(X - mean(X))/N definition of variance.
-   If you wish to use the unbiased, sum(X-mean(X)/(N-1) definition, then 
-   set the $ENV{UNBIAS}=1;
-
-   # And if you thought that was useful, then give a shout out to:
-   # Robert McGehee <xxxxxxxx@wso.williams.edu>, for he requested it.
-
 =head1 AUTHOR
 
     Please contact me with ANY suggestions, no matter how pedantic.
