@@ -1,10 +1,9 @@
 # vi:fdm=marker fdl=0
-# $Id: Correlation.pm,v 1.11 2004/03/23 13:01:42 jettero Exp $ 
+# $Id: Correlation.pm,v 1.7 2003/12/06 16:24:24 jettero Exp $ 
 
 package Statistics::Basic::Correlation;
 
 use strict;
-no warnings;
 use Carp;
 use Statistics::Basic::Vector;
 use Statistics::Basic::StdDev;
@@ -22,7 +21,7 @@ sub new {
 
     $this->{sd1} = new Statistics::Basic::StdDev($v1);
     $this->{sd2} = new Statistics::Basic::StdDev($v2);
-    $this->{cov} = new Statistics::Basic::CoVariance( $v1, $v2, undef, $this->{sd1}{v}{m}, $this->{sd2}{v}{m});
+    $this->{cov} = new Statistics::Basic::CoVariance($v1, $v2, undef, $this->{sd1}{v}{m}, $this->{sd2}{v}{m});
 
     $this->recalc;
 
@@ -38,7 +37,7 @@ sub recalc {
     my $s2 = $this->{sd2}->query;
 
     if( $s1 == 0 or $s2 == 0 ) {
-        warn "[recalc correlation] Standard deviation of 0.  Crazy infinite correlation detected.\n" if $ENV{DEBUG};
+        carp "Standard deviation of 0.  Crazy infinite correlation detected.";
 
         return undef;
     }
@@ -146,15 +145,6 @@ __END__
 
     A machine to calculate the correlation of given vectors.
 
-=head1 ENV VARIABLES
-
-=head2 DEBUG
-
-   Try setting $ENV{DEBUG}=1; or $ENV{DEBUG}=2; to see the internals.
-
-   Also, from your bash prompt you can 'DEBUG=1 perl ./myprog.pl' to
-   enable debugging dynamically.
-
 =head1 AUTHOR
 
     Please contact me with ANY suggestions, no matter how pedantic.
