@@ -1,10 +1,9 @@
 # vi:fdm=marker fdl=0
-# $Id: LeastSquareFit.pm,v 1.6 2004/03/23 13:01:42 jettero Exp $ 
+# $Id: LeastSquareFit.pm,v 1.2 2003/12/06 16:32:02 jettero Exp $ 
 
 package Statistics::Basic::LeastSquareFit;
 
 use strict;
-no warnings;
 use Carp;
 use Statistics::Basic::Vector;
 use Statistics::Basic::Variance;
@@ -35,16 +34,6 @@ sub new {
 sub recalc {
     my $this  = shift;
 
-    unless( $this->{vrx}->query ) {
-        unless( defined $this->{vrx}->query ) {
-            warn "[recalc LSF] undef variance...\n" if $ENV{DEBUG};
-        } else {
-            warn "[recalc LSF] narrowly avoided division by zero.  Something is probably wrong.\n" if $ENV{DEBUG};
-        }
-
-        return undef;
-    }
-
     $this->{beta}  = ($this->{cov}->query / $this->{vrx}->query);
     $this->{alpha} = ($this->{mny}->query - ($this->{beta} * $this->{mnx}->query));
 
@@ -153,15 +142,6 @@ __END__
 
     y = alpha + beta * x
 
-=head1 ENV VARIABLES
-
-=head2 DEBUG
-
-   Try setting $ENV{DEBUG}=1; or $ENV{DEBUG}=2; to see the internals.
-
-   Also, from your bash prompt you can 'DEBUG=1 perl ./myprog.pl' to
-   enable debugging dynamically.
-
 =head1 AUTHOR
 
     Please contact me with ANY suggestions, no matter how pedantic.
