@@ -1,10 +1,9 @@
 # vi:fdm=marker fdl=0
-# $Id: Mean.pm,v 1.16 2004/03/23 13:01:42 jettero Exp $ 
+# $Id: Mean.pm,v 1.13 2003/12/02 22:03:59 jettero Exp $ 
 
 package Statistics::Basic::Mean;
 
 use strict;
-no warnings;
 use Carp;
 
 use Statistics::Basic::Vector;
@@ -26,10 +25,8 @@ sub new {
     } elsif( ref($vector) eq "Statistics::Basic::Vector" ) {
         $this->{v} = $vector;
         $this->{v}->set_size( $set_size ) if defined $set_size;
-    } elsif( defined($vector) ) {
-        croak "argument to new() too strange";
     } else {
-        $this->{v} = new Statistics::Basic::Vector;
+        croak "argument to new() must be an arrayref or Statistics::Basic::Vector";
     }
 
     $this->recalc;
@@ -40,7 +37,7 @@ sub new {
 # recalc {{{
 sub recalc {
     my $this        = shift;
-    my $sum         = 0; 
+    my $sum         = 0;
     my $cardinality = $this->{v}->size;
 
     unless( $cardinality > 0 ) {
@@ -125,15 +122,6 @@ __END__
 
     A machine to calculate the mean of a given vector.
 
-=head1 ENV VARIABLES
-
-=head2 DEBUG
-
-   Try setting $ENV{DEBUG}=1; or $ENV{DEBUG}=2; to see the internals.
-
-   Also, from your bash prompt you can 'DEBUG=1 perl ./myprog.pl' to
-   enable debugging dynamically.
-
 =head1 AUTHOR
 
     Please contact me with ANY suggestions, no matter how pedantic.
