@@ -1,10 +1,9 @@
 # vi:fdm=marker fdl=0
-# $Id: Variance.pm,v 1.12 2004/03/23 13:01:42 jettero Exp $ 
+# $Id: Variance.pm,v 1.9 2003/12/02 22:03:59 jettero Exp $ 
 
 package Statistics::Basic::Variance;
 
 use strict;
-no warnings;
 use Carp;
 use Statistics::Basic::Mean;
 use Statistics::Basic::Vector;
@@ -26,10 +25,8 @@ sub new {
     } elsif( ref($vector) eq "Statistics::Basic::Vector" ) {
         $this->{v} = $vector;
         $this->{v}->set_size( $set_size ) if defined $set_size;
-    } elsif( defined($vector) ) {
-        croak "argument to new() too strange";
     } else {
-        $this->{v} = new Statistics::Basic::Vector;
+        croak "argument to new() must be an arrayref or Statistics::Basic::Vector";
     }
 
     $this->{m} = new Statistics::Basic::Mean($this->{v});
@@ -46,8 +43,6 @@ sub recalc {
     my $cardinality = $this->{v}->size;
     my $mean        = $this->{m}->query;
 
-    $cardinality -- if $ENV{UNBIAS};
-
     unless( $cardinality > 0 ) {
         $this->{variance} = undef;
 
@@ -135,24 +130,6 @@ __END__
 
     A machine to calculate the variance of a given vector.
 
-=head1 ENV VARIABLES
-
-=head2 DEBUG
-
-   Try setting $ENV{DEBUG}=1; or $ENV{DEBUG}=2; to see the internals.
-
-   Also, from your bash prompt you can 'DEBUG=1 perl ./myprog.pl' to
-   enable debugging dynamically.
-
-=head2 UNBIAS
-
-   This module uses the sum(X - mean(X))/N definition of variance.
-   If you wish to use the unbiased, sum(X-mean(X)/(N-1) definition, then 
-   set the $ENV{UNBIAS}=1;
-
-   # And if you thought that was useful, then give a shout out to:
-   # Robert McGehee <xxxxxxxx@wso.williams.edu>, for he requested it.
-
 =head1 AUTHOR
 
     Please contact me with ANY suggestions, no matter how pedantic.
