@@ -1,10 +1,9 @@
 # vi:fdm=marker fdl=0
-# $Id: Vector.pm,v 1.10 2004/03/23 13:01:42 jettero Exp $ 
+# $Id: Vector.pm,v 1.6 2003/12/02 21:31:02 jettero Exp $ 
 
 package Statistics::Basic::Vector;
 
 use strict;
-no warnings;
 use Carp;
 
 1;
@@ -66,8 +65,6 @@ sub set_size {
 sub size {
     my $this = shift;
 
-    return undef unless ref($this->{v});
-
     return int(@{ $this->{v} });
 }
 # }}}
@@ -98,6 +95,8 @@ sub insert {
 sub ginsert {
     my $this = shift;
 
+    croak "you must define a vector size before using insert()" unless defined $this->{s};
+
     for my $e (@_) {
         if( ref($e) ) {
             if( ref($e) eq "ARRAY" ) {
@@ -127,15 +126,15 @@ sub set_vector {
     } elsif( ref($vector) eq "Statistics::Basic::Vector") {
         $this->{s} = $vector->{s};
         $this->{v} = $vector->{v}; # this is really a clone I'd say ...
-    } elsif( defined $vector ) {
-        croak "argument to set_vector() too strange";
+    } else {
+        croak "argument to set_vector() must be an arrayref or Statistics::Basic::Vector";
     }
 
     if( defined $set_size ) {
         $this->set_size( $set_size );
     }
 
-    warn "[set_vector vector] [@{ $this->{v} }]\n" if $ENV{DEBUG} >= 2 and ref($this->{v});
+    warn "[set_vector vector] [@{ $this->{v} }]\n" if $ENV{DEBUG} >= 2;
 }
 # }}}
 
@@ -150,15 +149,6 @@ __END__
 
     A machine to calculate the mean of a given vector.
 
-=head1 ENV VARIABLES
-
-=head2 DEBUG
-
-   Try setting $ENV{DEBUG}=1; or $ENV{DEBUG}=2; to see the internals.
-
-   Also, from your bash prompt you can 'DEBUG=1 perl ./myprog.pl' to
-   enable debugging dynamically.
-
 =head1 AUTHOR
 
     Please contact me with ANY suggestions, no matter how pedantic.
